#!/bin/bash -l
# SALOME_MECA V2019 - Environnement file for the prerequisites and tools

export ROOT_SALOME="/home/user/salome_meca/V2019.0.3_universal"
export LC_NUMERIC=C

# To be sure to display icons in Gnome, we use the Gnome Configuration tool
gconfTool=`which gconftool-2`
if test -n "$gconfTool"; then
  $gconfTool --type boolean --set /desktop/gnome/interface/buttons_have_icons true
  $gconfTool --type boolean --set /desktop/gnome/interface/menus_have_icons true
fi

export SALOME_PLUGINS_PATH="${ROOT_SALOME}/plugins":${SALOME_PLUGINS_PATH}

if test -d "${ROOT_SALOME}/modules"; then
  export MODULES_ROOT_DIR="${ROOT_SALOME}/modules"
fi

if test ! -d "${ROOT_SALOME}/prerequisites"; then
  echo "=========================================="
  echo "Error: SALOME prerequisites path not found"
  echo "=========================================="
  exit 1
fi
export PREREQUISITES_ROOT_DIR="${ROOT_SALOME}/prerequisites"

if test ! -d "${ROOT_SALOME}/tools"; then
  echo "=================================="
  echo "Error: SALOME tools path not found"
  echo "=================================="
  exit 1
fi
export TOOLS_ROOT_DIR="${ROOT_SALOME}/tools"

export DEBIANFORSALOME=${PREREQUISITES_ROOT_DIR}/debianForSalome
export LD_LIBRARY_PATH=${DEBIANFORSALOME}/lib:/lib64:${LD_LIBRARY_PATH}

#------ tcl ------
export TCLDIR="${PREREQUISITES_ROOT_DIR}/Tcl-860"   # export needed by Code_Aster
export PATH=${TCLDIR}/bin:$PATH
export LD_LIBRARY_PATH=${TCLDIR}/lib:$LD_LIBRARY_PATH
export TCL_LIBRARY=${TCLDIR}/lib/tcl8.6
export TCL_LIBRARY_SO=${TCLDIR}/lib/libtcl8.6.so

#------ tk ------
export TKDIR="${PREREQUISITES_ROOT_DIR}/Tk-860"   # export needed by Code_Aster
export PATH=${TKDIR}/bin:$PATH
export LD_LIBRARY_PATH=${TKDIR}/lib:$LD_LIBRARY_PATH
export TK_LIBRARY=${TKDIR}/lib/tk8.6
export TK_LIBRARY_SO=${TKDIR}/lib/libtk8.6.so

#------ python ------
export PYTHONHOME="${PREREQUISITES_ROOT_DIR}/Python-365"
export PYTHONSTARTUP=${PYTHONHOME}/pythonrc.py
export PYTHON_INCLUDE=${PYTHONHOME}/include/python3.6
export PATH=${PYTHONHOME}/bin:${PATH}
export LD_LIBRARY_PATH=${PYTHONHOME}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=${PYTHONHOME}/lib/python3.6/site-packages:${PYTHONPATH}
# Temporary added for New Geom, to be removed after
# new geom environment variables have been made
# conform with SALOME variables
export PYTHON_ROOT_DIR=$PYTHONHOME

#------ sip ------
export SIP_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Sip-4193"
export PATH=${SIP_ROOT_DIR}/bin:${PATH}
export PYTHONPATH=${SIP_ROOT_DIR}/lib/python3.6/site-packages:${PYTHONPATH}
export LD_LIBRARY_PATH=${SIP_ROOT_DIR}/lib/python3.6/site-packages:${LD_LIBRARY_PATH}

#------ tix ------
export LD_LIBRARY_PATH="${TCLDIR}/lib/tclx8.4":$LD_LIBRARY_PATH

#------ omniORB ------
export OMNIORB_DIR="${PREREQUISITES_ROOT_DIR}/Omniorb-422"
export PATH=${OMNIORB_DIR}/bin:$PATH
export PYTHONPATH=${OMNIORB_DIR}/lib/python3.6/site-packages:${PYTHONPATH}
export LD_LIBRARY_PATH=$OMNIORB_DIR/lib:$LD_LIBRARY_PATH

#------ Cmake -----------
export PATH="${PREREQUISITES_ROOT_DIR}/Cmake-3121/bin":$PATH

#------ hdf5 ------
export HDF5HOME="${PREREQUISITES_ROOT_DIR}/Hdf5-1103"
export PATH=${HDF5HOME}/bin:$PATH
export LD_LIBRARY_PATH=${HDF5HOME}/lib:${LD_LIBRARY_PATH}
export HDF5_DISABLE_VERSION_CHECK=1

#------ boost ---------
export BOOSTDIR="${PREREQUISITES_ROOT_DIR}/Boost-1580"  # For check_boost.m4
export BOOST_ROOT="$BOOSTDIR"   # For CGAL
export BOOST_ROOT_DIR="$BOOSTDIR"
export LD_LIBRARY_PATH=$BOOST_ROOT/lib:$LD_LIBRARY_PATH

#------ Lapack ------
#export LAPACKDIR=${PREREQUISITES_ROOT_DIR}/Lapack-380
#export LD_LIBRARY_PATH="$LAPACKDIR/lib":${LD_LIBRARY_PATH}

#------ CGAL ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Cgal-40/lib":${LD_LIBRARY_PATH}

#------ CGNS Library ------
CGNSHOME=${PREREQUISITES_ROOT_DIR}/Cgnslib-331
export PATH=${CGNSHOME}/bin:$PATH
export LD_LIBRARY_PATH=${CGNSHOME}/lib:${LD_LIBRARY_PATH}

#------ togl ------
export LD_LIBRARY_PATH="${TCLDIR}/lib/Togl1.7":$LD_LIBRARY_PATH

#------- pygments ------
PYGMENTS_HOME="${PREREQUISITES_ROOT_DIR}/Pygments-202"
export PATH=${PYGMENTS_HOME}/bin:${PATH}
export PYTHONPATH=${PYGMENTS_HOME}/lib/python3.6/site-packages:${PYTHONPATH}

#------ graphviz ------
GRAPHVIZHOME="${PREREQUISITES_ROOT_DIR}/Graphviz-2380"
export PATH=${GRAPHVIZHOME}/bin:${PATH}
export LD_LIBRARY_PATH=${GRAPHVIZHOME}/lib/graphviz:${GRAPHVIZHOME}/lib:${LD_LIBRARY_PATH}

#------- libxml2 -------
export LIBXML_DIR="${PREREQUISITES_ROOT_DIR}/Libxml2-291"
export PATH=${LIBXML_DIR}/bin:${PATH}
export LD_LIBRARY_PATH=${LIBXML_DIR}/lib:${LD_LIBRARY_PATH}
# Temporary added for New Geom, to be removed after
# new geom environment variables have been made
# conform with SALOME variables
export LIBXML2_ROOT_DIR=$LIBXML_DIR

#------ swig ------
export SWIG_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Swig-3012"
export SWIG_LIB=${SWIG_ROOT_DIR}/share/swig/3.0.12
export SWIG_DIR=${SWIG_ROOT_DIR}/share/swig/3.0.12
export PATH=${SWIG_ROOT_DIR}/bin:$PATH

#------ Numpy ------
NUMPY_DIR="${PREREQUISITES_ROOT_DIR}/Numpy-1151"
export PATH=${NUMPY_DIR}/bin:${PATH}
export PYTHONPATH=${NUMPY_DIR}/lib/python3.6/site-packages:${PYTHONPATH}

# ------ Qt -------------
export QTDIR="${PREREQUISITES_ROOT_DIR}/Qt-591"
export PATH=${QTDIR}/bin:$PATH
export QT_PLUGIN_PATH=${QTDIR}/plugins
export LD_LIBRARY_PATH=${QTDIR}/lib:${LD_LIBRARY_PATH}
export QTVERSION=5
export LRELEASE=${QTDIR}/bin/lrelease
export QT_QPA_PLATFORM_PLUGIN_PATH=${QTDIR}/plugins/platforms

#-------PyQt ----------
export PYQT_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Pyqt-590"
export PYQT_SIPS=${PYQT_ROOT_DIR}/share/sip
export PYUIC=${PYQT_ROOT_DIR}/bin/pyuic5
export PYTHONPATH=${PYQT_ROOT_DIR}/lib/python3.6/site-packages:${PYTHONPATH}
export PATH=${PYQT_ROOT_DIR}/bin:${PATH}

#------- Matplotlib ------
export MATPLOTLIB_HOME="${PREREQUISITES_ROOT_DIR}/Matplotlib-222"
export PYTHONPATH=${MATPLOTLIB_HOME}/lib/python3.6/site-packages:${PYTHONPATH}
export MPLCONFIGDIR="${HOME}/.config/salome/matplotlib-2.2.2" # Useful to avoid changing the config files used by the system matplotlib

#---------- MuParser -------------------
export LD_LIBRARY_PATH=${PREREQUISITES_ROOT_DIR}/Muparser-132/lib:${LD_LIBRARY_PATH}

#---------- NLopt -------------------
export NLOPT_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Nlopt-242"
export LD_LIBRARY_PATH=${PREREQUISITES_ROOT_DIR}/Nlopt-242/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=${NLOPT_ROOT_DIR}/lib/python3.6/site-packages:${PYTHONPATH}

#------ R -----------
export R_HOME="${PREREQUISITES_ROOT_DIR}/R-2151/lib/R"
export LD_LIBRARY_PATH=${R_HOME}/lib:${LD_LIBRARY_PATH}
export PATH=${R_HOME}/bin:${PATH}

#------ rotrpackage -----------
export R_LIBS="${PREREQUISITES_ROOT_DIR}/Rotrpackage-146":${R_LIBS}

# ------ Scipy ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Scipy-0191/lib/python3.6/site-packages":${PYTHONPATH}

#------- docutils ------
export DOCUTILS_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Docutils-012"
export PATH=${DOCUTILS_ROOT_DIR}/bin:${PATH}
export PYTHONPATH=${DOCUTILS_ROOT_DIR}/lib/python3.6/site-packages:${PYTHONPATH}

#------- jinja ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Jinja-273/lib/python3.6/site-packages":${PYTHONPATH}

#------ TBB. ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Tbb-424/lib":${LD_LIBRARY_PATH}

#---------- OpenTURNS -------------------
export OPENTURNS_HOME="${PREREQUISITES_ROOT_DIR}/Openturns_tool-112"
export LD_LIBRARY_PATH=${OPENTURNS_HOME}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=${OPENTURNS_HOME}/lib/python3.6/site-packages:${PYTHONPATH}

#------ OpenTURNS FFTW module ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Openturns_fftw-06/lib/python3.6/site-packages":${PYTHONPATH}
export LD_LIBRARY_PATH=${PREREQUISITES_ROOT_DIR}/Openturns_fftw-06/lib:${LD_LIBRARY_PATH}

#------ cppunit ------
export CPPUNIT_ROOT="${PREREQUISITES_ROOT_DIR}/Cppunit-1132"
export PATH=${CPPUNIT_ROOT}/bin:$PATH
export LD_LIBRARY_PATH=${CPPUNIT_ROOT}/lib:${LD_LIBRARY_PATH}

#---------- libBatch -------------------
export LIBBATCH_ROOT_DIR="${TOOLS_ROOT_DIR}/Libbatch-V2_4_1"
export LD_LIBRARY_PATH=${LIBBATCH_ROOT_DIR}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=$LIBBATCH_ROOT_DIR/lib/python3.6/site-packages:${PYTHONPATH}

#------ omniORBpy ------
export OMNIORBPY_DIR="${PREREQUISITES_ROOT_DIR}/Omniorbpy-422"
export PYTHONPATH=${OMNIORBPY_DIR}/lib/python3.6/site-packages:${PYTHONPATH}
export PYTHONPATH=${OMNIORBPY_DIR}/lib/python3.6/site-packages/omniidl_be:${PYTHONPATH}

#------ Py2cpp ------
export PY2CPP_ROOT_DIR="${TOOLS_ROOT_DIR}/Py2cpp-v10"
export LD_LIBRARY_PATH=${PY2CPP_ROOT_DIR}/lib:${LD_LIBRARY_PATH}

#------ Metis ------
export METISDIR="${PREREQUISITES_ROOT_DIR}/Metis_aster-510_aster4"    # export needed for compilation of medsplitter/partitinner
export PATH=${METISDIR}/bin:$PATH
export LD_LIBRARY_PATH=${METISDIR}/lib:${LD_LIBRARY_PATH}

#------ miss3d ------
export MISS3D_DIR=${TOOLS_ROOT_DIR}/Miss3d-67_aster2     # export necessaire a Code_Aster/outils/run_miss3d
export PATH=${MISS3D_DIR}:$PATH

#------ freetype ------
FREETYPE_ROOT="${PREREQUISITES_ROOT_DIR}/Freetype-29"
export PATH=${FREETYPE_ROOT}/bin:$PATH
export LD_LIBRARY_PATH=${FREETYPE_ROOT}/lib:${LD_LIBRARY_PATH}

#------ gl2ps ------
export GL2PS_INSTALL_DIR="${PREREQUISITES_ROOT_DIR}/Gl2ps-14020170729"
export LD_LIBRARY_PATH=${GL2PS_INSTALL_DIR}/lib:$LD_LIBRARY_PATH

#------ FreeImage ------
FREEIMAGE_ROOT="${PREREQUISITES_ROOT_DIR}/Freeimage-3170"
export FreeImage_version=3.17.0
export LD_LIBRARY_PATH=${FREEIMAGE_ROOT}/lib:${LD_LIBRARY_PATH}

#------ cas ------
export CASROOT="${PREREQUISITES_ROOT_DIR}/Occ-730p3"
export OPENCASCADE_ROOT_DIR=${CASROOT}
export OpenCASCADE_ROOT_DIR=${CASROOT}
export LD_LIBRARY_PATH=${CASROOT}/lib:${LD_LIBRARY_PATH}
# Variable for Foundation Classes :
export CSF_UnitsLexicon=${CASROOT}/src/UnitsAPI/Lexi_Expr.dat
export CSF_UnitsDefinition=${CASROOT}/src/UnitsAPI/Units.dat
# Variable for DataExchange :
export CSF_SHMessageStd=${CASROOT}/src/SHMessageStd
export CSF_SHMessage=${CASROOT}/src/SHMessage
export CSF_XSMessage=${CASROOT}/src/XSMessage
# Variable for Font :
export CSF_MDTVFontDirectory=${CASROOT}/src/FontMFT
export CSF_MDTVTexturesDirectory=${CASROOT}/src/Textures
# Needed for HYDRO module :
export CSF_StandardDefaults=${CASROOT}/src/StdResource
export CSF_PluginDefaults=${CASROOT}/src/StdResource
export CSF_StandardLiteDefaults=${CASROOT}/src/StdResource
export CSF_XmlOcafResource=${CASROOT}/src/XmlOcafResource
# Temporary added for New Geom, to be removed after
# new geom environment variables have been made
# conform with SALOME variables
export PATH=${CASROOT}:${PATH}

#------ ParaView ------
export PVHOME="${PREREQUISITES_ROOT_DIR}/Paraview-v560p1"
export PATH=${PVHOME}/bin:$PATH
export PVVERSION=5.6
export PV_PLUGIN_PATH="$(readlink -f ${PVHOME}/lib/paraview-${PVVERSION}):${PV_PLUGIN_PATH}"
export LD_LIBRARY_PATH=${PVHOME}/lib/paraview-${PVVERSION}:$LD_LIBRARY_PATH
export PYTHONPATH=${PVHOME}/lib/paraview-${PVVERSION}:${PYTHONPATH}
export PYTHONPATH=${PVHOME}/lib/paraview-${PVVERSION}/site-packages:${PYTHONPATH}
export PYTHONPATH=${PVHOME}/lib/paraview-${PVVERSION}/site-packages/vtkmodules:${PYTHONPATH}

#------ qwt ------
export QWTHOME="${PREREQUISITES_ROOT_DIR}/Qwt-612" # pour PARAVIS
export QWT_INCLUDES=${QWTHOME}/include
export LD_LIBRARY_PATH=${QWTHOME}/lib:${LD_LIBRARY_PATH}

#------ Opencv ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Opencv-24135/lib":${LD_LIBRARY_PATH}

#------ Adao ------
export ADAO_ENGINE_ROOT_DIR="${TOOLS_ROOT_DIR}/Adao-V9_3_0_0"
export PYTHONPATH=${ADAO_ENGINE_ROOT_DIR}/lib/python3.6/site-packages:${PYTHONPATH}

#------ Adao_interface ------
export ADAO_INTERFACE_ROOT_DIR="${TOOLS_ROOT_DIR}/Adao_interface-227a599c1e22d"
export LD_LIBRARY_PATH=${ADAO_INTERFACE_ROOT_DIR}/lib:${LD_LIBRARY_PATH}

#------ HOMARD_ASTER  ------
export HOMARD_ASTER_ROOT_DIR="${TOOLS_ROOT_DIR}/Homard_aster-1112_aster"
export PATH=${HOMARD_ASTER_ROOT_DIR}:$PATH

#------ codeaster-frontend ------
export ASTER_ROOT="${TOOLS_ROOT_DIR}/Code_aster_frontend-20190"
export PATH=${ASTER_ROOT}/bin:${PATH}
export LD_LIBRARY_PATH=${ASTER_ROOT}/lib:$LD_LIBRARY_PATH
export PYTHONPATH=${ASTER_ROOT}/lib/python3.6/site-packages:$PYTHONPATH

#------ med fichier ------
export MED3HOME="${PREREQUISITES_ROOT_DIR}/Medfichier-400"
export MEDFICHIER_INSTALL_DIR="${PREREQUISITES_ROOT_DIR}/Medfichier-400"
export PATH=${MED3HOME}/bin:${PATH}
export LD_LIBRARY_PATH=${MED3HOME}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=${MED3HOME}/lib/python3.6/site-packages:${PYTHONPATH}

#------ ydefx ------
export YDEFX_ROOT_DIR="${MODULES_ROOT_DIR}/YDEFX_V9_3_0"
export LD_LIBRARY_PATH=${YDEFX_ROOT_DIR}/lib:${LD_LIBRARY_PATH}

#------ Metis ------
export METISDIR="${PREREQUISITES_ROOT_DIR}/Metis-510"    # export needed for compilation of medsplitter/partitinner
export PATH=${METISDIR}/bin:$PATH
export LD_LIBRARY_PATH=${METISDIR}/lib:${LD_LIBRARY_PATH}

#------ Scotch ------
export SCOTCHDIR="${PREREQUISITES_ROOT_DIR}/Scotch-604"    # export needed for compilation of medsplitter/partitionner
export PATH=${SCOTCHDIR}/bin:${PATH}

#------ MEDCoupling ------
export MEDCOUPLING_ROOT_DIR="${TOOLS_ROOT_DIR}/Medcoupling-V9_3_0"
export PATH=${MEDCOUPLING_ROOT_DIR}/bin:${PATH}
export LD_LIBRARY_PATH=${MEDCOUPLING_ROOT_DIR}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=${MEDCOUPLING_ROOT_DIR}/lib/python3.6/site-packages:${PYTHONPATH}

#------ ASTERSTUDY module ------
export ASTERSTUDY_ROOT_DIR="${MODULES_ROOT_DIR}/ASTERSTUDY_201903"
# asrun
export PYTHONPATH=${ASTER_ROOT}/lib/python3.6/site-packages:${PYTHONPATH}
# Services Python du module
export PYTHONPATH=${ASTERSTUDY_ROOT_DIR}/lib/python3.6/site-packages/salome:${PYTHONPATH}
export PYTHONPATH=${ASTERSTUDY_ROOT_DIR}/lib/python3.6/site-packages:${PYTHONPATH}
export QT_QPA_PLATFORMTHEME=gtk2
# ------- end of ASTERSTUDY module ------

# ------- DISTENE ---------
export DISTENE_LICENSE_FILE="Use global envvar: DLIM8VAR"
export DLIM8VAR="dlim8 1:1:29030@10.122.51.15/005056010130::9de2ce714bcb5ec8ced9926a1087298ebeca6affe852286633abe41cb4a85b4b"
export DISTENE_LICENCE_FILE_FOR_YAMS='"$DISTENE_LICENSE_FILE"'
export DISTENE_LICENCE_FILE_FOR_MGCLEANER='"$DISTENE_LICENSE_FILE"'

# ------ MeshGems -------------
MESHGEMSHOME="${PREREQUISITES_ROOT_DIR}/Meshgems-286"
MESHGEMS_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Meshgems-286"

export PATH=${MESHGEMSHOME}/bin/Linux_64:$PATH
export LD_LIBRARY_PATH=${MESHGEMSHOME}/lib/Linux_64:${LD_LIBRARY_PATH}

#------- SMESH -------
SMESH_DIR=${MODULES_ROOT_DIR}/SMESH_V9_3_0
export PYTHONPATH=${SMESH_DIR}/share/salome/plugins/smesh/Verima:${PYTHONPATH}

#------ OpenTURNS ROBOPT module ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Openturns_robopt-04/lib/python3.6/site-packages":${PYTHONPATH}
export LD_LIBRARY_PATH=${PREREQUISITES_ROOT_DIR}/Openturns_robopt-04/lib:${LD_LIBRARY_PATH}

#------- Xlutils ------
export XLUTILS_HOME="${PREREQUISITES_ROOT_DIR}/Xlutils-200"
export PYTHONPATH=${XLUTILS_HOME}/lib/python3.6/site-packages:${PYTHONPATH}

#------ ECREVISSE  ------
export ECREVISSE_ROOT_DIR="${TOOLS_ROOT_DIR}/Ecrevisse-322"

#------ cython -----------
export CYTHON_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Cython-0252"
export PATH=${CYTHON_ROOT_DIR}/bin:${PATH}
export PYTHONPATH=${CYTHON_ROOT_DIR}/lib/python3.6/site-packages:${PYTHONPATH}

#------- h5py ------
export PYTHONPATH=${PREREQUISITES_ROOT_DIR}/H5py-280/lib/python3.6/site-packages:${PYTHONPATH}

#---------- gmsh -------------------
export GMSHHOME="${PREREQUISITES_ROOT_DIR}/Gmsh-414"
export PATH=${GMSHHOME}/bin:${PATH}
export LD_LIBRARY_PATH=${GMSHHOME}/lib:${LD_LIBRARY_PATH}

#------ OpenTURNS PMML module ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Openturns_pmml-16/lib/python3.6/site-packages":${PYTHONPATH}
export LD_LIBRARY_PATH=${PREREQUISITES_ROOT_DIR}/Openturns_pmml-16/lib:${LD_LIBRARY_PATH}

#------- libxslt -------
export LIBXSLT_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Libxslt-1128"
export PATH=${LIBXSLT_ROOT_DIR}/bin:${PATH}
export LD_LIBRARY_PATH=${LIBXSLT_ROOT_DIR}/lib:${LD_LIBRARY_PATH}

#------- Paravis ------
export PARAVIS_DIR=${MODULES_ROOT_DIR}/PARAVIS_V9_3_0
export PV_PLUGIN_PATH="${PARAVIS_DIR}/lib/paraview":${PV_PLUGIN_PATH}
export PV_MACRO_PATH=${HOME}/.config/salome/Macros

#------- Xlwt ------
export XLWT_HOME="${PREREQUISITES_ROOT_DIR}/Xlwt-130"
export PYTHONPATH=${XLWT_HOME}/lib/python3.6/site-packages:${PYTHONPATH}

#---------- Homard -------------------
export HOMARD_REP_EXE="${TOOLS_ROOT_DIR}/Homard_tool-1112hdf51103med400"
export HOMARD_EXE=homard

#---------- netgen -------------------
export NETGENHOME="${TOOLS_ROOT_DIR}/Netgen-531"
export LD_LIBRARY_PATH=${NETGENHOME}/lib:${LD_LIBRARY_PATH}

#------ Zcracks -----------
export ZCRACKSHOME="${PREREQUISITES_ROOT_DIR}/Zcracks-292p2"
export PYTHONPATH=${ZCRACKSHOME}/plugin:${PYTHONPATH}


#------- GnuplotPy ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Gnuplotpy-183k/lib/python3.6/site-packages":${PYTHONPATH}

#------ pillow ------
export PILLOWHOME="${PREREQUISITES_ROOT_DIR}/Pillow-342"
export PATH=${PILLOWHOME}/bin:$PATH
export PYTHONPATH=${PILLOWHOME}/lib/python3.6/site-packages:${PYTHONPATH}

#------ OpenTURNS Wrapy module------
export PYTHONPATH=${PREREQUISITES_ROOT_DIR}/Openturns_wrapy-07_EDF/lib/python3.6/site-packages:${PYTHONPATH}

#------- Xlrd ------
export XLRD_HOME="${PREREQUISITES_ROOT_DIR}/Xlrd-120"
export PYTHONPATH=${XLRD_HOME}/lib/python3.6/site-packages:${PYTHONPATH}

#------ eigen ------
export EIGEN_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Eigen-334"

#------ planegcs ------
export PLANEGCS_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Planegcs-018"
export LD_LIBRARY_PATH=${PLANEGCS_ROOT_DIR}/lib:${LD_LIBRARY_PATH}

#------- Shaper ------
export SHAPER_ROOT_DIR=${MODULES_ROOT_DIR}/SHAPER_V9_3_0
export PATH=${SHAPER_ROOT_DIR}/bin/salome:${SHAPER_ROOT_DIR}/lib/salome:${PATH}
export PYTHONPATH=${SHAPER_ROOT_DIR}/bin/salome:${SHAPER_ROOT_DIR}/lib/salome:${PYTHONPATH}
export LD_LIBRARY_PATH=${SHAPER_ROOT_DIR}/bin/salome:${SHAPER_ROOT_DIR}/lib/salome:${LD_LIBRARY_PATH}
export PLUGINS_CONFIG_FILE=${SHAPER_ROOT_DIR}/share/salome/resources/shaper
export SHAPERResources=${SHAPER_ROOT_DIR}/share/salome/resources/shaper
export SALOME_MODULES_ORDER='SHAPER:GEOM:SMESH'

#------ PARAVISADDONS ------
export PARAVISADDONS_ROOT_DIR="${TOOLS_ROOT_DIR}/Paravisaddons-V9_3_0"
export PV_PLUGIN_PATH=${PARAVISADDONS_ROOT_DIR}/lib:${PV_PLUGIN_PATH}
export LD_LIBRARY_PATH=${PARAVISADDONS_ROOT_DIR}/lib:${LD_LIBRARY_PATH}

#------ OpenTURNS MIXMOD module ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Openturns_mixmod-07/lib/python3.6/site-packages":${PYTHONPATH}
export LD_LIBRARY_PATH=${PREREQUISITES_ROOT_DIR}/Openturns_mixmod-07/lib:${LD_LIBRARY_PATH}

#------ MUMPS ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Mumps-512_aster6/SEQ/lib":${LD_LIBRARY_PATH}

#------ Eficas_Nouveau -----------
export EFICAS_NOUVEAU_ROOT="${TOOLS_ROOT_DIR}/Eficas_nouveau-V9_3_2"
export EFICAS_ROOT="${TOOLS_ROOT_DIR}/Eficas_nouveau-V9_3_2"

#------ SALOMEMECA_EXTRA ------
SALOMEMECA_EXTRA_ROOT_DIR="${TOOLS_ROOT_DIR}/Salomemeca_extra-201903_public"


#------ gmsh_bin ------
export GMSH_BIN_DIR=${PREREQUISITES_ROOT_DIR}/Gmsh_bin-2120Linux64/bin
export PATH=${GMSH_BIN_DIR}:$PATH

#------ MFRONT ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Mfront-TFEL321/lib":${LD_LIBRARY_PATH}
export PATH="${PREREQUISITES_ROOT_DIR}/Mfront-TFEL321/bin":"$PATH"
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Mfront-TFEL321/lib/python3.6/site-packages":$PYTHONPATH
export TFELHOME="${PREREQUISITES_ROOT_DIR}/Mfront-TFEL321"
export TFELVERS="3.2.1"

#------ code_aster - Template environment_shell ------
export ASTER_STABLE="${TOOLS_ROOT_DIR}/Code_aster_stable-v144_smeca"
if [ -d /usr/lib/atlas-base/atlas ]; then
    if [ -z "$LD_LIBRARY_PATH" ]; then
        export LD_LIBRARY_PATH=/usr/lib/atlas-base/atlas
    else
        export LD_LIBRARY_PATH=/usr/lib/atlas-base/atlas:$LD_LIBRARY_PATH
    fi
fi


#------ EUROPLEXUS module ------
export EUROPLEXUS_ROOT_DIR="${MODULES_ROOT_DIR}/EUROPLEXUS_201901"
# Services Python du module
export PYTHONPATH=${EUROPLEXUS_ROOT_DIR}/lib/python3.6/site-packages/salome:${PYTHONPATH}
export PYTHONPATH=${EUROPLEXUS_ROOT_DIR}/lib/python3.6/site-packages:${PYTHONPATH}
# ------- end of EUROPLEXUS module ------

#------ OpenTURNS SVM module ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Openturns_svm-05/lib/python3.6/site-packages":${PYTHONPATH}
export LD_LIBRARY_PATH=${PREREQUISITES_ROOT_DIR}/Openturns_svm-05/lib:${LD_LIBRARY_PATH}

#------ OpenTURNS MORRIS module ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Openturns_morris-05/lib/python3.6/site-packages":${PYTHONPATH}
export LD_LIBRARY_PATH=${PREREQUISITES_ROOT_DIR}/Openturns_morris-05/lib:${LD_LIBRARY_PATH}

export OTMORRIS_HOME="${PREREQUISITES_ROOT_DIR}/Openturns_morris-05"

#------- OTGUI -------
OTGUI_DIR=${TOOLS_ROOT_DIR}/Otgui-v61
export LD_LIBRARY_PATH=${OTGUI_DIR}/lib:${LD_LIBRARY_PATH}
export PATH=${OTGUI_DIR}/bin:${PATH}
export PYTHONPATH=${OTGUI_DIR}/lib/python3.6/site-packages:${PYTHONPATH}
export OTGUI_HTML_DOCUMENTATION_PATH=${OTGUI_DIR}/share/otgui/doc/html/

#------ OpenTURNS LM module ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Openturns_lm-07/lib/python3.6/site-packages":${PYTHONPATH}
export LD_LIBRARY_PATH=${PREREQUISITES_ROOT_DIR}/Openturns_lm-07/lib:${LD_LIBRARY_PATH}

#------- lxml ------
export LXML_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Lxml-340"
export PYTHONPATH=${LXML_ROOT_DIR}/lib/python3.6/site-packages:${PYTHONPATH}
